Class: Google::Cloud::NetworkConnectivity::V1::CreateDestinationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::NetworkConnectivity::V1::CreateDestinationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/networkconnectivity/v1/data_transfer.rb
Overview
Request message to create a Destination resource.
Instance Attribute Summary collapse
-
#destination ⇒ ::Google::Cloud::NetworkConnectivity::V1::Destination
Required.
-
#destination_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#destination ⇒ ::Google::Cloud::NetworkConnectivity::V1::Destination
Returns Required. The Destination resource to create.
439 440 441 442 |
# File 'proto_docs/google/cloud/networkconnectivity/v1/data_transfer.rb', line 439 class CreateDestinationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_id ⇒ ::String
Returns Required. The ID to use for the Destination resource, which becomes the
final component of the Destination resource name.
439 440 441 442 |
# File 'proto_docs/google/cloud/networkconnectivity/v1/data_transfer.rb', line 439 class CreateDestinationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The name of the parent resource.
439 440 441 442 |
# File 'proto_docs/google/cloud/networkconnectivity/v1/data_transfer.rb', line 439 class CreateDestinationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server can ignore the request if it has already been completed. The server waits for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and
the request times out. If you make the request again with the same request
ID, the server can check if original operation with the same request ID
was received, and if so, can ignore the second request. This prevents
clients from accidentally creating duplicate Destination
resources.
The request ID must be a valid UUID with the exception that zero UUID (00000000-0000-0000-0000-000000000000) isn't supported.
439 440 441 442 |
# File 'proto_docs/google/cloud/networkconnectivity/v1/data_transfer.rb', line 439 class CreateDestinationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |