Class: Google::Rpc::ErrorInfo
- Inherits:
-
Object
- Object
- Google::Rpc::ErrorInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/rpc/error_details.rb
Overview
Describes the cause of the error with structured details.
Example of an error when contacting the "pubsub.googleapis.com" API when it is not enabled:
{ "reason": "API_DISABLED"
"domain": "googleapis.com"
"metadata": {
"resource": "projects/123",
"service": "pubsub.googleapis.com"
}
}
This response indicates that the pubsub.googleapis.com API is not enabled.
Example of an error that is returned when attempting to create a Spanner instance in a region that is out of stock:
{ "reason": "STOCKOUT"
"domain": "spanner.googleapis.com",
"metadata": {
"availableRegions": "us-central1,us-east2"
}
}
Defined Under Namespace
Classes: MetadataEntry
Instance Attribute Summary collapse
-
#domain ⇒ ::String
The logical grouping to which the "reason" belongs.
-
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
Additional structured details about this error.
-
#reason ⇒ ::String
The reason of the error.
Instance Attribute Details
#domain ⇒ ::String
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'proto_docs/google/rpc/error_details.rb', line 72 class ErrorInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#metadata ⇒ ::Google::Protobuf::Map{::String => ::String}
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'proto_docs/google/rpc/error_details.rb', line 72 class ErrorInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#reason ⇒ ::String
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'proto_docs/google/rpc/error_details.rb', line 72 class ErrorInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MetadataEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |